###Install via pip:

    pip install git+https://github.com/tBaxter/Tango.git

###For a new project, run the [Tango Starter Kit](https://github.com/tBaxter/tango-starter-kit): 

    django-admin.py startproject --template=https://github.com/tBaxter/tango-starter-kit/archive/master.zip test_project

*Note: test_project should (of course) be the name of your project*

### Run syncdb or South.

And start adding content. That's it.